from drf_prettify_json_serializer_field.fields import PrettifyDataFromJsonField
from drf_prettify_json_serializer_field.fields import (Charfield,
                                                       EmailField,
                                                       DecimalField,
                                                       IntegerField)
